[![PyPI](https://img.shields.io/pypi/v/dvg-qdeviceio)](https://pypi.org/project/dvg-qdeviceio)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/dvg-qdeviceio)](https://pypi.org/project/dvg-qdeviceio)
[![Build Status](https://travis-ci.org/Dennis-van-Gils/python-dvg-qdeviceio.svg?branch=master)](https://travis-ci.org/Dennis-van-Gils/python-dvg-qdeviceio)
[![Coverage Status](https://coveralls.io/repos/github/Dennis-van-Gils/python-dvg-qdeviceio/badge.svg?branch=master)](https://coveralls.io/github/Dennis-van-Gils/python-dvg-qdeviceio?branch=master)
[![License: MIT](https://img.shields.io/badge/License-MIT-purple.svg)](https://github.com/Dennis-van-Gils/python-dvg-qdeviceio/blob/master/LICENSE.txt)
[![CodeStyle: Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# DvG_QDeviceIO
PyQt5 module containing the framework for multithreaded communication and periodical data acquisition for an I/O device.

Stable beta. Documentation will be added next. Within a month (at July 2020) I expect a proper release.
